.. currentmodule:: numpy

==========================
NumPy 1.22.2 Release Notes
==========================

The NumPy 1.22.2 is maintenance release that fixes bugs discovered after the
1.22.1 release. Notable fixes are:

- Several build related fixes for downstream projects and other platforms.
- Various Annotation fixes/additions.
- Numpy wheels for Windows will use the 1.41 tool chain, fixing downstream link
  problems for projects using NumPy provided libraries on Windows.
- Deal with CVE-2021-41495 complaint.

The Python versions supported for this release are 3.8-3.10.

Contributors
============

A total of 14 people contributed to this release.  People with a "+" by their
names contributed a patch for the first time.

* Andrew J. Hesford +
* Bas van Beek
* Brénainn Woodsend +
* Charles Harris
* Hood Chatham
* Janus Heide +
* Leo Singer
* Matti Picus
* Mukulika Pahari
* Niyas Sait
* Pearu Peterson
* Ralf Gommers
* Sebastian Berg
* Serge Guelton

Pull requests merged
====================

A total of 21 pull requests were merged for this release.

* `#20842 <https://github.com/numpy/numpy/pull/20842>`__: BLD: Add NPY_DISABLE_SVML env var to opt out of SVML
* `#20843 <https://github.com/numpy/numpy/pull/20843>`__: BUG: Fix build of third party extensions with Py_LIMITED_API
* `#20844 <https://github.com/numpy/numpy/pull/20844>`__: TYP: Fix pyright being unable to infer the ``real`` and ``imag``...
* `#20845 <https://github.com/numpy/numpy/pull/20845>`__: BUG: Fix comparator function signatures
* `#20906 <https://github.com/numpy/numpy/pull/20906>`__: BUG: Avoid importing ``numpy.distutils`` on import numpy.testing
* `#20907 <https://github.com/numpy/numpy/pull/20907>`__: MAINT: remove outdated mingw32 fseek support
* `#20908 <https://github.com/numpy/numpy/pull/20908>`__: TYP: Relax the return type of ``np.vectorize``
* `#20909 <https://github.com/numpy/numpy/pull/20909>`__: BUG: fix f2py's define for threading when building with Mingw
* `#20910 <https://github.com/numpy/numpy/pull/20910>`__: BUG: distutils: fix building mixed C/Fortran extensions
* `#20912 <https://github.com/numpy/numpy/pull/20912>`__: DOC,TST: Fix Pandas code example as per new release
* `#20935 <https://github.com/numpy/numpy/pull/20935>`__: TYP, MAINT: Add annotations for ``flatiter.__setitem__``
* `#20936 <https://github.com/numpy/numpy/pull/20936>`__: MAINT, TYP: Added missing where typehints in ``fromnumeric.pyi``
* `#20937 <https://github.com/numpy/numpy/pull/20937>`__: BUG: Fix build_ext interaction with non numpy extensions
* `#20938 <https://github.com/numpy/numpy/pull/20938>`__: BUG: Fix missing intrinsics for windows/arm64 target
* `#20945 <https://github.com/numpy/numpy/pull/20945>`__: REL: Prepare for the NumPy 1.22.2 release.
* `#20982 <https://github.com/numpy/numpy/pull/20982>`__: MAINT: f2py: don't generate code that triggers ``-Wsometimes-uninitialized``.
* `#20983 <https://github.com/numpy/numpy/pull/20983>`__: BUG: Fix incorrect return type in reduce without initial value
* `#20984 <https://github.com/numpy/numpy/pull/20984>`__: ENH: review return values for PyArray_DescrNew
* `#20985 <https://github.com/numpy/numpy/pull/20985>`__: MAINT: be more tolerant of setuptools >= 60
* `#20986 <https://github.com/numpy/numpy/pull/20986>`__: BUG: Fix misplaced return.
* `#20992 <https://github.com/numpy/numpy/pull/20992>`__: MAINT: Further small return value validation fixes
